import history_read_f
import numpy as np
import matplotlib
from matplotlib import pyplot as plt
from mpl_toolkits.mplot3d import Axes3D
import matplotlib.tri as mtri
import argparse
import os
#import path_config
from scipy import fftpack

def read(directory):
    history_file_name = os.path.join(directory, "frc_history.out")
    history_read_f.histroy_parameters.filename(history_file_name)
    history_read_f.histroy_parameters.history_read()
    # print(history_read_f.histroy_parameters.phi_hist[100])

def fft(tsize, steps, phi_real, phi_imag):
    tstep_diag = tsize
    x = phi_real + 1j * phi_imag
    y = fftpack.fft(x)
    y = np.fft.fftshift(y)
    frange = np.linspace(-np.pi/tstep_diag, np.pi*(steps-2)/tstep_diag/steps ,steps)
    return frange, y

def main(directory='.', endtime=0):
    realstep = history_read_f.histroy_parameters.realstep
    directory = os.path.abspath(directory)
    print(directory)
    RHO0=6.42e-2
    aion=2
    t_unit=np.sqrt(aion)/RHO0
    read(directory)
    if endtime > 0 and endtime <= realstep:
        realstep=endtime
    tstep_diag = history_read_f.histroy_parameters.tstep_diag
    print('delta_t', tstep_diag, 'steps', realstep)
    time_range = list(range(realstep)) * tstep_diag / t_unit
    fig = plt.figure()
    ax = fig.add_subplot(221)
    #ax.plot(time_range, history_read_f.histroy_parameters.fieldmode[1,:])
    #ax.plot(time_range, history_read_f.histroy_parameters.fieldmode[0,:])
    #phi_tmp = np.zeros(history_read_f.histroy_parameters.ndstep)
    #for istep in range(2, history_read_f.histroy_parameters.ndstep-2):
    #    phi_tmp[istep] = sum(history_read_f.histroy_parameters.phi_hist[istep-2:istep+3])/5
    phi_hist = history_read_f.histroy_parameters.phi_hist[:realstep]
    phi_real = history_read_f.histroy_parameters.phi_real_hist[:realstep]
    phi_imag = history_read_f.histroy_parameters.phi_imag_hist[:realstep]
    #phi_hist = phi_hist - np.mean(phi_hist)
    #phi_real = phi_real - np.mean(phi_real)
    #phi_imag = phi_imag - np.mean(phi_imag)
    ax.plot(time_range, phi_real)
    ax.plot(time_range, phi_imag)
    #ax.plot(time_range, phi_hist)
    ax.legend([r"$\Re{\phi}$", "$\Im{\phi}$"])

    ax3 = fig.add_subplot(222)
    phi_mod = np.sqrt(phi_real**2 + phi_imag**2)
    phi_log = np.log(phi_mod)
    ax3.plot(time_range, phi_log)
    plt.title("$\ln\phi$")

    ax4 = fig.add_subplot(223)
    norm_real = phi_real / phi_mod
    norm_imag = phi_imag / phi_mod
    ax4.plot(time_range, norm_real)
    ax4.plot(time_range, norm_imag)

    ax2 = fig.add_subplot(224)
    tsize = history_read_f.histroy_parameters.tstep_diag / t_unit
    freq, y = fft(tsize, realstep, phi_real, phi_imag)
    #freq, y = fft(tsize, realstep, phi_hist, 0)
    maxloc = np.argmax(np.absolute(y))
    maxfreq = freq[maxloc]
    ax2.plot(freq, np.absolute(y))
    plt.xlim([-5,5])
    plt.title("$\omega=%f$" % maxfreq)
    plt.ion()
    plt.show(block=True)


if __name__ == "__main__":
    parser = argparse.ArgumentParser()
    parser.add_argument("--end",action='store',type=int,default=0)
    parser.add_argument("--dir",action='store',type=str,default='.')
    args = parser.parse_args()
    main(directory=args.dir, endtime=args.end)
